#include "image.h"

#include <SDL/SDL_image.h>
#include <SDL/SDL_opengl.h>
#include <stdio.h>
#include <iostream>

/**
 * Creates a new image, from the file specified.
 *
 * @param file the file storing the image.
 */
Image::Image(const char* file) {

	SDL_Surface* temp = IMG_Load(file);
	if (!temp) {
		printf("Unable to load bitmap: %s\n", SDL_GetError());
		return;
	}
  
	GLenum texture_format;
	GLint colors = temp->format->BytesPerPixel;
	if (colors == 4) {
		if (temp->format->Rmask == 0x000000ff)
			texture_format = GL_RGBA;
		else
			texture_format = GL_BGRA;
	} else if (colors == 3) {
		if (temp->format->Rmask == 0x000000ff)
			texture_format = GL_RGB;
		else
			texture_format = GL_BGR;
	} else {
		printf("Image is not truecolour: %s\n", file);
		return;
	}

	glGenTextures(1, &texture);
	glBindTexture(GL_TEXTURE_2D, texture);
	glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
	glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
	glTexImage2D(GL_TEXTURE_2D, 0, colors, temp->w, temp->h, 0, texture_format, GL_UNSIGNED_BYTE, temp->pixels);

	width = (temp->w);
	height = (temp->h);
	width /= 64;
	height /= 64;
  
	SDL_FreeSurface(temp);
  
}

/**
 * Draws the image at the specified x and y co-ordinates.
 *
 * @param x the x co-ordinate to draw at.
 * @param y the y co-ordinate to draw at.
 */
void Image::draw(float x, float y, float w, float h) const {
	
	glColor3f(1, 1, 1);
	glBindTexture(GL_TEXTURE_2D, texture);
	glBegin(GL_QUADS);
		glTexCoord2f(0, 0);	glVertex3f(x, y + h, 0);
		glTexCoord2f(0, 1); glVertex3f(x, y, 0 );
		glTexCoord2f(1, 1); glVertex3f(x + w, y, 0);
		glTexCoord2f(1, 0);	glVertex3f(x + w, y + h, 0);
	glEnd();
	glBindTexture(GL_TEXTURE_2D, 0);

}

