#include "input.h"
#include "particle.h"
#include "bullet.h"
#include "player.h"
#include "window.h"
#include "SDL_opengl.h"

#include "image.h"
#include "number.h"

Player* phil;
Player* john;

int frame = 0;

void init () {
	// Try and initialise a window.
	if (! Window::init(480, 160, "Phil vs. John") ) {
		exit(1);
	}
	
	Number::init();
	
	phil = new Player(50);
	john = new Player(430);
}

void update () {
	for (bullet_iterator it = bullets.begin(); it != bullets.end(); /* Nothing */) {
		Bullet* bullet = *it;
		
		bullet->update();
		
		if (bullet->hit) {
			it = bullets.erase(it);
		} else {
			it++;
		}
	}
	
	john->update(frame);
	phil->update(frame);
	
	frame++;
	
	for (particle_iterator it = particles.begin(); it != particles.end(); /* Nothing */) {
		Particle* particle = *it;
		
		particle->update();
		
		if (particle->y < 2) {
			it = particles.erase(it);
		} else {
			it++;
		}
	}
}

void draw () {
	
	glClearColor(0.3f, 0.6f, 0.3f, 1.0f);
	
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
	
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	glOrtho(0, 480, 0, 160, -1, 1);
	
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	
	glBegin(GL_QUADS);
		for (particle_iterator it = particles.begin(); it != particles.end(); it++) {
			Particle* particle = *it;
			
			particle->draw();
		}
		
		for (bullet_iterator it = bullets.begin(); it != bullets.end(); it++) {
			Bullet* bullet = *it;
			
			bullet->draw();
		}
	glEnd();
	
	glEnable(GL_BLEND);
	glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
	glEnable(GL_TEXTURE_2D);
	
	phil->draw();
	john->draw();
	
	glDisable(GL_TEXTURE_2D);
	glDisable(GL_BLEND);
	
	phil->drawWall();
	john->drawWall();
	
	SDL_GL_SwapBuffers();
}

int main (int argc, char** argv) {
	init();

	int previousTime = SDL_GetTicks();
	int step = 20; // ms
	int diff = 0;

	// Update/render loop.
	while (true) {
		// Check for input.
		Input::checkEvents();

		// Update the scene.
		update();

		// Draw the scene.
		draw();

		// Wait only if we have drawn quicker than the timer step.
		diff = SDL_GetTicks() - previousTime;
		
		if (diff < step) {
			SDL_Delay(step - diff);
		}
		
		previousTime = SDL_GetTicks();
	}

	return 0;
}

