#include "particle.h"

#include "SDL_opengl.h"
#include <math.h>
#include <stdlib.h>

std::list<Particle*> particles;

inline float randf () {
	return (rand() % 10000) / 10000.0f;
}

Particle::Particle (float _x, float _y) : x(_x), y(_y) {
	vx = randf() * 10 - 5;
	vy = randf() * 5 + 2;
	vrot = randf() * 0.2f + 0.1f;
	
	if (x > 240) {
		r = 174.0f / 255.0f;
		g = 56.0f / 255.0f;
		b = 56.0f / 255.0f;
	} else {
		r = 125.0f / 255.0f;
		g = 200.0f / 255.0f;
		b = 255.0f / 255.0f;
	}
	
	size = randf() * 8 + 3;
}

void Particle::update () {
	x += vx;
	y += vy;
	
	vy -= 0.2f;
	vx *= 0.99f;
	
	rot += vrot;
	
	float speedSq = vx * vx + vy * vy;
	
	float colourChange = 1 - speedSq / 500.0f;
	
	r *= colourChange;
	g *= colourChange;
	b *= colourChange;
}

void Particle::draw () const {
	float _sin = sin(rot) * size;
	float _cos = cos(rot) * size;
	
	glColor3f(r, g, b);
	
	glVertex2f(x - _cos, y + _sin);
	glVertex2f(x - _sin, y - _cos);
	glVertex2f(x + _cos, y - _sin);
	glVertex2f(x + _sin, y + _cos);
}

