#include "player.h"
#include "particle.h"
#include "bullet.h"
#include "colour.h"
#include "input.h"

Player::Player (float _x) : damagetimer(0), x(_x) {
	if (x < 240) {
		image = new Image("images/phil.png");
		imageSad = new Image("images/phil-sad.png");
	} else {
		image = new Image("images/john.png");
		imageSad = new Image("images/john-sad.png");
	}
}

void Player::update (int frame) {
	if (damagetimer > 0) {
		damagetimer--;
		
		for (int i = 0; i < 1; i++) {	
			particles.push_back(new Particle(x, (x < 240) ? 50 : 30));
		}
	}
	
	if (x < 240) {
		flip = Input::isPressed(SDLK_z);
	} else {
		flip = Input::isPressed(SDLK_m);
	}
	
	if (frame % 100 == 25 && damagetimer == 0) {
		if (x < 240) {
			bullets.push_back(new Bullet(x + 30));
		} else {
			bullets.push_back(new Bullet(x - 30));
		}
	}
}

void Player::hit () {
	damagetimer = 105;
	
	damage.number++;
}

void Player::draw () const {
	if (damagetimer > 0) {
		imageSad->draw(x - 40, 0, 80, 80);
	} else {
		image->draw(x - 40, 0, 80, 80);
	}
	
	if (x < 240) {
		damage.draw(430, 120);
	} else {
		damage.draw(50, 120);
	}
}

void Player::drawWall () const {
	const float wallNear = 80;
	const float wallFar = 85;
		
	if (x < 240) { // Phil
		Colour c = flip ? johnColour : philColour;
		
		glBegin(GL_QUADS);
			glColor3ub(c.r / 4, c.g / 4, c.b / 4);
			glVertex3f(x + wallNear, 90, 0);
			glVertex3f(x + wallNear, 0, 0 );
			
			glColor3ub(c.r, c.g, c.b);
			glVertex3f(x + wallFar, 0, 0);
			glVertex3f(x + wallFar, 90, 0);
		glEnd();
	} else { // John
		Colour c = flip ? philColour : johnColour;
		
		glBegin(GL_QUADS);
			glColor3ub(c.r, c.g, c.b);
			glVertex3f(x - wallFar, 90, 0);
			glVertex3f(x - wallFar, 0, 0 );
			
			glColor3ub(c.r / 4, c.g / 4, c.b / 4);
			glVertex3f(x - wallNear, 0, 0);
			glVertex3f(x - wallNear, 90, 0);
		glEnd();
	}
}


