#include "SDL.h"
#include "SDL_opengl.h"

#include "window.h"

// TODO: fullscreenable from start
// TODO: resizable

SDL_Surface* Window::s_screen = 0;

int Window::s_width = 800;
int Window::s_height = 600;

int Window::s_fullscreen_width;
int Window::s_fullscreen_height;

int Window::s_old_width;
int Window::s_old_height;

bool Window::s_fullscreen = false;

/**
 * Create a new Window with the specified dimensions and title.
 *
 * @param width The width of the window.
 * @param height The height of the window.
 * @param title The title of the window.
 */
bool Window::init(const int width, const int height, const char* title) {
	
	s_width = width;
	s_height = height;
	
	s_old_width = width;
	s_old_height = height;
	
	// Centre the window.
	/*putenv("SDL_VIDEO_WINDOW_POS");
	putenv("SDL_VIDEO_CENTERED=1");
	getenv("SDL_VIDEO_WINDOW_POS");
	getenv("SDL_VIDEO_CENTERED");*/

	// Check if we can initialise SDL video.
	if (SDL_Init(SDL_INIT_VIDEO) != 0) {
		fprintf(stderr, "Unable to initalise SDL: %s\n", SDL_GetError());
		return false;
	}    
	atexit(SDL_Quit);

	const SDL_VideoInfo* videoInfo = SDL_GetVideoInfo();
	
	s_fullscreen_width = videoInfo->current_w;
	s_fullscreen_height = videoInfo->current_h;
	
	if (s_fullscreen) {
		s_width = s_fullscreen_width;
		s_height = s_fullscreen_height;
	}
	
	SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);  

	SDL_WM_SetCaption(title, NULL);
	
	return reset();

}

bool Window::reset () {
	Uint32 flags = SDL_DOUBLEBUF | SDL_HWSURFACE | SDL_OPENGL | SDL_ANYFORMAT;
	
	if (s_fullscreen) {flags |= SDL_FULLSCREEN; }
	
	s_screen = SDL_SetVideoMode(s_width, s_height, 32, flags);
	
	if (s_screen == NULL) {
		fprintf(stderr, "Unable to set video mode: %s\n", SDL_GetError());
		return false;
	}
	
	glViewport(0, 0, s_width, s_height);
	
	//Drawing::init();
	
	return true;
}

void Window::setFullscreen (bool b) {
	s_fullscreen = b;
	
	if (s_fullscreen) {
		s_old_width = s_width;
		s_old_height = s_height;
		
		if (true) {
			s_width = s_fullscreen_width;
			s_height = s_fullscreen_height;
		}
	} else if (true) {
		s_width = s_old_width;
		s_height = s_old_height;
	}
	
	reset();
}

void Window::toggleFullscreen () {
	setFullscreen(! s_fullscreen);
}

void Window::resize (const int w, const int h) {
	s_width = w;
	s_height = h;
	
	reset();
}

